# -*- indent-tabs-mode: nil -*-

import MAPICore
from MAPI.Defs import *

class SPropValue :
    def __init__(self, ulPropTag, Value):
        self.ulPropTag = ulPropTag
        self.Value = Value
    def __repr__(self):
        if(PROP_TYPE(self.ulPropTag) == MAPICore.PT_BINARY):
            Value = bin2hex(self.Value)
        elif(PROP_TYPE(self.ulPropTag) == MAPICore.PT_UNICODE):
            return "{ %08X:u'%s' }" % (self.ulPropTag, self.Value)
        else:
            Value = self.Value
        return "{ %08X:'%s' }" % (self.ulPropTag, Value)
    def __cmp__(self, other):
        if self.ulPropTag != other.ulPropTag:
            return cmp(self.ulPropTag,other.ulPropTag)
        return cmp(self.Value,other.Value)
    def __hash__(self):
        return hash(self.ulPropTag) + hash(self.Value)
        
    def __eq__(self, other):
        x = self.__dict__ == other.__dict__
        return x

class SSort:
    def __init__(self, ulPropTag, ulOrder):
        self.ulPropTag = ulPropTag
        self.ulOrder = ulOrder
        
    def __repr__(self):
        sorts = [ 'ASC', 'DESC' ]
        return "{ %08X %s }" % (self.ulPropTag, sorts[self.ulOrder])

class SSortOrderSet:
    def __init__(self, sorts, cCategories, cExpanded):
        self.aSort = sorts
        self.cCategories = cCategories
        self.cExpanded = cExpanded
      
    def __repr__(self):
        return "{ %s, %d, %d }" % (repr(self.aSort), self.cCategories, self.cExpanded)

class MAPINAMEID:
    def __init__(self, guid, kind, id):
        self.guid = guid
        self.kind = kind
        self.id = id
        
    def __repr__(self):
        if (self.kind == MAPICore.MNID_ID):
            return "{ %s MNID_ID %s }" % (bin2hex(self.guid), self.id)
        else:
            return "{ %s MNID_STRING %s }" % (bin2hex(self.guid), self.id)

class SPropProblem:
    def __init__(self, index, tag, scode):
        self.index = index
        self.tag = tag
        self.scode = scode

class SAndRestriction:
    def __init__(self, sub):
        self.rt = MAPICore.RES_AND
        self.lpRes = sub
        
class SOrRestriction:
    def __init__(self, sub):
        self.rt = MAPICore.RES_OR
        self.lpRes = sub
        
class SNotRestriction:
    def __init__(self, sub):
        self.rt = MAPICore.RES_NOT
        self.lpRes = sub
        
class SContentRestriction:
    def __init__(self, fuzzy, proptag, prop):
        self.rt = MAPICore.RES_CONTENT
        self.ulFuzzyLevel = fuzzy
        self.ulPropTag = proptag
        self.lpProp = prop
        
class SBitMaskRestriction:
    def __init__(self, relBMR, ulPropTag, ulMask):
        self.rt = MAPICore.RES_BITMASK
        self.relBMR = relBMR
        self.ulPropTag = ulPropTag
        self.ulMask = ulMask

class SPropertyRestriction:
    def __init__(self, relop, ulPropTag, prop):
        self.rt = MAPICore.RES_PROPERTY
        self.ulPropTag = ulPropTag
        self.relop = relop
        self.lpProp = prop

class SComparePropsRestriction:
    def __init__(self, relop, ulPropTag1, ulPropTag2):
        self.rt = MAPICore.RES_COMPAREPROPS
        self.relop = relop
        self.ulPropTag1 = ulPropTag1
        self.ulPropTag2 = ulPropTag2
        
class SSizeRestriction:
    def __init__(self, relop, ulPropTag, cb):
        self.rt = MAPICore.RES_SIZE
        self.relop = relop
        self.ulPropTag = ulPropTag
        self.cb = cb
        
class SExistRestriction:
    def __init__(self, proptag):
        self.rt = MAPICore.RES_EXIST
        self.ulPropTag = proptag
        
class SSubRestriction:
    def __init__(self, ulSubObject, res):
        self.rt = MAPICore.RES_SUBRESTRICTION
        self.ulSubObject = ulSubObject
        self.lpRes = res
        
class SCommentRestriction:
    def __init__(self, res, prop):
        self.rt = MAPICore.RES_COMMENT
        self.lpRes = res
        self.lpProp = prop

class MAPIError(Exception):
    def __init__(self, hr):
        self.hr = hr
        
    def __repr__(self):
        return "MAPI error %X" % (self.hr)

    def __str__(self):
        return self.__repr__()

class READSTATE:
    def __init__(self, SourceKey, ulFlags):
        self.SourceKey = SourceKey
        self.ulFlags = ulFlags

class ECUSER:
    def __init__(self, Username, Password, Email, FullName, Servername = None, Class = 0x10001, IsAdmin = False, IsHidden = False, Capacity = 0):
        self.Username = Username
        self.Password = Password
        self.Email = Email
        self.FullName = FullName
        self.Servername = Servername
        self.Class = Class
        self.IsAdmin = IsAdmin
        self.IsHidden = IsHidden
        self.Capacity = Capacity
